==> qt-creator-opensource-src-4.6.2.zip: qt-creator-opensource-src-4.6.2/src/libs/clangsupport/pchmanagerserverproxy.cpp <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#include "pchmanagerserverproxy.h"

#include "cmbendmessage.h"
#include "messageenvelop.h"
#include "pchmanagerclientinterface.h"
#include "removepchprojectpartsmessage.h"
#include "updatepchprojectpartsmessage.h"

#include <QIODevice>
#include <QVector>

namespace ClangBackEnd {

PchManagerServerProxy::PchManagerServerProxy(PchManagerClientInterface *client, QIODevice *ioDevice)
    : BaseServerProxy(client, ioDevice)
{
}

void PchManagerServerProxy::end()
{
    m_writeMessageBlock.write(EndMessage());
}

void PchManagerServerProxy::updatePchProjectParts(UpdatePchProjectPartsMessage &&message)
{
    m_writeMessageBlock.write(message);
}

void PchManagerServerProxy::removePchProjectParts(RemovePchProjectPartsMessage &&message)
{
    m_writeMessageBlock.write(message);
}

} // namespace ClangBackEnd

==> qt-creator-opensource-src-4.8.1.zip: qt-creator-opensource-src-4.8.1/src/libs/clangsupport/pchmanagerserverproxy.cpp <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#include "pchmanagerserverproxy.h"

#include "endmessage.h"
#include "messageenvelop.h"
#include "pchmanagerclientinterface.h"
#include "removegeneratedfilesmessage.h"
#include "removeprojectpartsmessage.h"
#include "updategeneratedfilesmessage.h"
#include "updateprojectpartsmessage.h"

#include <QIODevice>
#include <QVector>

namespace ClangBackEnd {

PchManagerServerProxy::PchManagerServerProxy(PchManagerClientInterface *client, QIODevice *ioDevice)
    : BaseServerProxy(client, ioDevice)
{
}

void PchManagerServerProxy::end()
{
    m_writeMessageBlock.write(EndMessage());
}

void PchManagerServerProxy::updateProjectParts(UpdateProjectPartsMessage &&message)
{
    m_writeMessageBlock.write(message);
}

void PchManagerServerProxy::removeProjectParts(RemoveProjectPartsMessage &&message)
{
    m_writeMessageBlock.write(message);
}

void PchManagerServerProxy::updateGeneratedFiles(UpdateGeneratedFilesMessage &&message)
{
    m_writeMessageBlock.write(message);
}

void PchManagerServerProxy::removeGeneratedFiles(RemoveGeneratedFilesMessage &&message)
{
    m_writeMessageBlock.write(message);
}

} // namespace ClangBackEnd
